# AI-Bash: 智能命令行工具

一个基于大模型的命令行工具，可以将自然语言需求转换为对应平台的命令行命令。

## 功能介绍

- 接收用户的自然语言描述
- 调用大模型API将需求转换为命令行命令
- 自动识别用户的操作系统和命令行环境
- 根据当前平台生成最适合的命令
- 支持自定义API密钥、主机地址和模型名称
- 生成命令并在用户确认后执行
- 分析命令执行结果，提取有用信息

## 快速开始

安装:
```bash
uv tool install ai_bash
# 更新
uv tool upgrade ai-bash

# 支持三个命令: ai ai-bash ai_bash
```

使用:
```bash
# 基本用法(生成命令并等待用户回车后执行)
ai 查一下当前目录的文件路径

# 只生成命令不执行
ai 列出所有进程 --no-exec

# 只输出纯文本命令，便于手动复制
ai 查找大文件 --copy

# 自动将命令复制到剪贴板，可直接粘贴使用
ai 查找大文件 --clipboard

# 执行命令后交互式分析结果
ai 获取最新10条git提交 --qa

# 查看帮助信息
ai --help
```

## 配置

初始化并查看配置:
```bash
# 显示配置文件路径，如果不存在则创建
ai --init

# 强制创建新配置文件(覆盖已有配置)
ai --init --force
```

配置文件位于用户主目录下的`.cmd_ai`文件:
```
# 必需的API密钥
OPENAI_API_KEY=你的OpenAI API密钥
```

## 交互式命令分析功能

使用`--qa` `-q` 选项来启用交互式命令分析功能:

```bash
# 执行git命令并进入交互式分析模式
ai 获取最近10次git提交日志 --qa
```

执行命令后，工具会:
1. 显示命令执行结果
2. 询问您是否需要AI分析结果
3. 如果需要，您可以输入具体的分析需求，例如：
   - "总结最近的工作内容"
   - "分析提交频率"
   - "找出所有关于bug修复的提交"
4. AI会根据您的需求分析命令输出
5. 分析完成后，还可以继续提出其他分析需求

## 文档与贡献

- 详细使用说明和开发指南：[文档.md](文档.md)
- 贡献代码规范：[CONTRIBUTING.md](CONTRIBUTING.md) 